###############################################################################
# Orkid Build System
# Copyright 2010-2018, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

VERSION = "v1.2.5"

import os, tarfile
from obt import dep, host, path, cmake, git, make, command, log, env
from obt.deco import Deco
from obt.wget import wget
from obt.command import Command

deco = Deco()

###############################################################################

class moltenvk(dep.Provider):

  def __init__(self): ############################################
    super().__init__("moltenvk")
    #print(options)
    self.source_root = path.builds()/"moltenvk"
    self.build_dest = path.builds()/"moltenvk"/".build"
    self.manifest = path.manifests()/"moltenvk"
    self.OK = self.manifest.exists()
    #self._archlist = ["x86_64"]
    self._oslist = ["Darwin"]
    self.sdk_dir = self.source_root/"Package"/"Latest"/"MoltenVK"
    self.build_lib_dir = self.sdk_dir/"dylib"/"macOS"
  def __str__(self): ##########################################################

    return "MoltenVK (github-%s)" % VERSION

  def wipe(self): #############################################################
    os.system("rm -rf %s"%self.source_root)
    os.system("rm -rf %s"%self.build_dest)

  def env_init(self):
    log.marker("registering Vulkan(%s) <MoltenVK> SDK"%VERSION)
    env.prepend("LD_LIBRARY_PATH",self.sdk_dir/"dylib")
    #env.append("PATH",self.sdk_dir/"bin")
    env.set("VULKAN_SDK",self.sdk_dir) # for cmake
    env.set("OBT_VULKAN_VERSION","MoltenVK-%s"%(VERSION)) # for OBT internal
    env.set("OBT_VULKAN_ROOT",self.sdk_dir) # for OBT internal
    env.set("VK_ICD_FILENAMES",self.build_lib_dir/"MoltenVK_icd.json")

  def build(self): ##########################################################

    #glfw = dep.require("glfw")

    if not self.source_root.exists():
      git.Clone("https://github.com/KhronosGroup/MoltenVK",self.source_root,VERSION)

    os.chdir(self.source_root)

    command.system(["./fetchDependencies --macos"])
    cmd = ["xcodebuild", "build", 
           "-project", '"MoltenVKPackaging.xcodeproj"',
           "-scheme", '"MoltenVK Package (macOS only)"',
           "-configuration", '"Debug"']
    ok = (0 == command.system(cmd))
    if ok:
      cmd = ["cp",self.build_lib_dir/"libMoltenVk.dylib",path.libs()/"libMoltenVk.dylib"]
      ok = (0 == command.system(cmd))
      if ok:
        cmd = ["cp","-r","Package/Latest/MoltenVK/include/*",path.includes()]
        ok = (0 == command.system(cmd))
        if ok:
          # moltenvlk does not automatically install shaderc
          cmd = ["brew","install","--overwrite", "shaderc"]
          ok = (0 == command.system(cmd))
    return ok

# Package/Debug/MoltenVKShaderConverter/Tools/MoltenVKShaderConverter <stage>/bin



###############################################################################
# Orkid Build System
# Copyright 2010-2022, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

import os, multiprocessing 
from obt import target, host

###############################################################################

class OsDescriptor:
  def __init__(self):
    self.id = ""
    self.version_id = ""
    self.version_codename = ""

###############################################################################

def descriptorLinux():
  try:
    import distro
    INFO = distro.name(), distro.version()
    print(INFO)
    print(dir(distro))
    osd = OsDescriptor()
    osd.id = distro.name()
    osd.version_id = distro.version()
    osd.version_codename = distro.codename()
    print(osd)
    #assert(False)
    return osd
  except ModuleNotFoundError:
    try:
      import os_release
      INFO = os_release.current_release()
      print(INFO)
      osd = OsDescriptor()
      print(osd)
      osd.id = INFO.id
      osd.version_id = INFO.version_id
      osd.version_codename = INFO.version_codename
      return osd
    except ModuleNotFoundError:
      try:
        import lsb_release
        INFO = lsb_release.get_os_release()
        print(INFO)
        osd = OsDescriptor()
        osd.id = INFO["ID"]
        osd.version_id = INFO["RELEASE"]
        osd.version_codename = INFO["CODENAME"]
        print(osd)
        return osd
      except ModuleNotFoundError:
        print("python module 'lsb_release' or 'os_release' is not installed")
        return {}
      
###############################################################################

def descriptorMacos():
  try:
    import os_release
    INFO = os_release.current_release()
    print(INFO)
    osd = OsDescriptor()
    print(osd)
    osd.id = INFO.id
    osd.version_id = INFO.version_id
    osd.version_codename = INFO.version_codename
    return osd
  except ModuleNotFoundError:
    try:
      import lsb_release
      INFO = lsb_release.get_os_release()
      print(INFO)
      osd = OsDescriptor()
      osd.id = INFO["ID"]
      osd.version_id = INFO["RELEASE"]
      osd.version_codename = INFO["CODENAME"]
      print(osd)
      return osd
    except ModuleNotFoundError:
      print("python module 'lsb_release' or 'os_release' is not installed")
      return {}
    
###############################################################################

def descriptor():
  if host.IsLinux:
    return descriptorLinux()
  elif host.IsOsx:
    return descriptorMacos()
  print("UHOH")
  return {}
  
  


from obt import dep, pip, path, dep, pathtools, command, log, env
Command = command.Command
from yarl import URL
###############################################################################

VERSION = "master"

class litex(dep.Provider):

  def __init__(self): ############################################
    super().__init__("litex")
    build_dest = path.builds()/"litex"
    self.build_dest = build_dest
    self.manifest = path.manifests()/"litex"
    self.OK = self.manifest.exists()
    self.python = self.declareDep("python")
    self._oslist = ["Linux"]
    self._archlist = ["x86_64"]

  def build(self): ############################################################
      pathtools.mkdir(self.build_dest,clean=True)
      pathtools.chdir(self.build_dest)
      uri = URL("https://raw.githubusercontent.com")/"enjoy-digital"/"litex"/VERSION/"litex_setup.py"
      commands = [Command(["wget",uri])]
      commands += [Command(["chmod","ugo+x","litex_setup.py"])]
      commands += [Command(["./litex_setup.py","init","install"])]
      commands += [Command(["echo", "building litex unfortunately requires sudo for now.."])]
      commands += [Command(["sudo","./litex_setup.py","gcc"])]
      commands += [Command(["pip3","install","git+https://github.com/litex-hub/pythondata-software-picolibc.git"])]
      commands += [Command(["pip3","install","meson"])]

      for item in commands:
      	ret = item.exec()
      	if ret != 0:
      	  return ret
      return 0

  ########

  def env_init(self):
    log.marker("registering LITEX(%s) SDK"%VERSION)
    LITEX_ROOT = self.build_dest
    LITEX_BOARDS = LITEX_ROOT/"litex-boards"/"litex_boards"
    GCC_RISCV = LITEX_ROOT/"riscv64-unknown-elf-gcc-8.3.0-2019.08.0-x86_64-linux-ubuntu14"
    env.set("LITEX_ROOT",LITEX_ROOT)
    env.set("LITEX_BOARDS",LITEX_BOARDS)
    env.append("PATH",LITEX_BOARDS/"targets")
    env.append("PATH",GCC_RISCV/"bin")

  def env_goto(self):
    return { "litex": self.build_dest }

  ########

  def on_build_shell(self):
    pathtools.mkdir(self.build_dest,clean=False)
    return command.subshell( directory=self.build_dest,
                             prompt = "LITEX",
                             environment = dict() )

  ########

  def areRequiredSourceFilesPresent(self):
    return (self.build_dest/"setup.py").exists()

  def areRequiredBinaryFilesPresent(self):
    return (self.build_dest/"litex-boards"/"litex_boards"/"targets"/"digilent_nexys4.py").exists()



#!/usr/bin/env python3
import os, sys, subprocess, shlex, argparse
from pathlib import Path

parser = argparse.ArgumentParser(description='jinja-build')
parser.add_argument('--directory', metavar="directory", required=True, help='directory' )
parser.add_argument('--basedir', metavar="basedir", required=True, help='basedir' )
args = vars(parser.parse_args())


SCRIPTDIR=Path(os.path.dirname(os.path.realpath(__file__)))
DIRECTORY = Path(args["directory"])
BASEDIR = Path(args["basedir"])

#print(SCRIPTDIR)
#########################################
LOGTEXTPATH=DIRECTORY/"stdout.log"
LOGPROC=DIRECTORY/"stdout.proc"
LOGHTML=DIRECTORY/"stdout.html"
#########################################
#print("SHA=%s"%SHA)
#print("SCRIPTDIR=%s"%SCRIPTDIR)
#print("DIRECTORY=%s"%DIRECTORY)
#print("LOGPATH=%s"%LOGPATH)
#print("LOGHTML=%s"%LOGHTML)
LOGTEXT = LOGTEXTPATH.read_text()
#########################################
# redact paths
#########################################
searchstr = str(BASEDIR).replace("/","\/")
replacestr = "[JOBDIR]"
result = str(LOGTEXT).replace(searchstr,replacestr)
#########################################
searchstr = "/home/builder"
replacestr = "[HOMEDIR]"
result = result.replace(searchstr,replacestr)
#########################################
with open(LOGPROC,mode="w") as f:
  f.write(result)
#########################################
cmd = ["aha","--black","--title", "yo", "-f",LOGPROC]
result = subprocess.check_output(cmd,universal_newlines=True)

with open(LOGHTML,mode="w") as f:
  f.write(result)

#



###############################################################################
# Orkid Build System
# Copyright 2010-2022, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################
from obt import dep, path, pathtools, log, env, command, host
import os
###############################################################################
class orkid(dep.StdProvider):
  name = "orkid"

  def __init__(self):
    super().__init__(orkid.name)
    self._oslist = ["Linux","Darwin"]
    self._archlist = ["x86_64","aarch64"]
    self._allow_build_in_subspaces = True 
    ################################
    # default orkid_src_dir is in builds/orkid (from dep fetcher)
    ################################

    self.orkid_src_dir = path.builds()/"orkid"

    ################################
    # if ORKID_IS_MAIN_PROJECT set,
    #  use that as orkid_src_dir
    ################################

    x = path.Path(os.environ["OBT_PROJECT_DIR"])
    self._userworkingcopy = (x/"orkid.cmake").exists()
      
    if self._userworkingcopy:
      self.orkid_src_dir = x
      assert(self.orkid_src_dir==x)
      self.source_root = x
      self.build_src = x

    ################################

    for item in self.deplist:
      self.declareDep(item)

    ################################

    self._builder = dep.CustomBuilder(orkid.name)

    self.builddir = path.subspace_python_build_dir/"orkid"/".build"
    self._builder._builddir = self.builddir

    ###########################################################

    self._builder._cleanbuildcommands += [self._outer_build_command]
    self._builder._incrbuildcommands += [self._outer_build_command]

  ########################################################################
  @property
  def github_repo(self):
    return "tweakoz/orkid"
  ########

  @property
  def revision(self):
    return "toz-opengl-eol"

  @property
  def _fetcher(self):
    if self._userworkingcopy:
      pathtools.mkdir(self.builddir,parents=True)
      return dep.NopFetcher(name=orkid.name)
    else:
      return dep.GithubFetcher(name=orkid.name,
                               repospec=self.github_repo,
                               revision=self.revision,
                               recursive=True,
                               shallow=False)

  ########

  @property
  def _envinitcommands(self):
    return ["obt.env.launch.py",
      "--stack", path.stage(),
      "--novars", # use parent environment variables
      "--project", path.builds()/"orkid",
    ]

  ########

  @property
  def _inner_build_command(self):
    ork_build_script = self.orkid_src_dir/"obt.project"/"bin"/"ork.build.py"
    inner_build_command = [str(ork_build_script), "--builddir", str(self.builddir)]
    if dep._globals.getOption("debug"):
      inner_build_command += ["--debug"]
    if dep._globals.getOption("verbose"):
      inner_build_command += ["--verbose"]
    if dep._globals.getOption("serial"):
      inner_build_command += ["--serial"]
    #inner_build_command += ["--trace"]
    return inner_build_command

  ########

  @property
  def _outer_build_command(self):
    return command.Command(self._envinitcommands +
                           ["--command", " ".join(self._inner_build_command)])

  ########

  @property
  def deplist(self):
    deplist = []

    deplist += ["cmake"]
    deplist += ["pydefaults"]
    deplist += ["python"]
    deplist += ["pybind11"]
    deplist += ["openexr"]
    deplist += ["oiio"]
    deplist += ["assimp"]
    deplist += ["rapidjson"]
    deplist += ["luajit"]
    deplist += ["glfw"]
    deplist += ["lexertl14"]
    deplist += ["parsertl14"]
    deplist += ["easyprof"]
    deplist += ["eigen"]
    deplist += ["glm"]
    deplist += ["bullet"]
    deplist += ["rtmidi"]
    deplist += ["zmq"]
    deplist += ["cppzmq"]
    deplist += ["cpppeglib"]
    deplist += ["klein"]
    deplist += ["portaudio"]
    deplist += ["sigslot"]
    deplist += ["openblas"]
    deplist += ["igl"]
    #deplist += ["libsurvive"]

    if host.IsX86_64:
      deplist += ["ispctexc"]
      deplist += ["openvdb"]

    #if ork.host.IsOsx: # until moltenvk fixed on big sur
    #   ork.dep.require(["moltenvk"])
    
    if host.IsLinux:
      deplist += ["vulkan"]
      deplist += ["rtmidi"]
      if host.IsX86_64:
        deplist += ["openvr"]
        #deplist += ["nvtt"]
    elif host.IsDarwin:
      deplist += ["moltenvk"]

    return deplist

  ########
  def update(self):
    self.builddir.chdir()
    self._fetcher.update()

  ########
  def on_build_shell(self):
    shell_cmd = command.Command([
      "obt.env.launch.py",
      "--stack", path.stage(),
      "--project", path.builds()/"orkid",
      "--chdir", path.builds()/"orkid"
    ])
    return shell_cmd.exec()

  ########

  def env_init(self):
    log.marker("registering Orkid(%s) SDK @ %s"%(self.revision,self.orkid_src_dir))
    env.set("ORKID_WORKSPACE_DIR",self.orkid_src_dir)
    env.set("ORKID_LEV2_EXAMPLES_DIR",self.orkid_src_dir/"ork.lev2"/"examples")

  ########

  def env_goto(self):
    return { "orkid": self.orkid_src_dir }
    
  ########
  def find_paths(self):
    return [self.source_root/"ork.core",self.source_root/"ork.lev2"]

  def areRequiredSourceFilesPresent(self):
    return (self.source_root/"orkid.cmake").exists()

  def areRequiredBinaryFilesPresent(self):
    return (path.libs()/("libork_core.%s"%self.shlib_extension)).exists()



###############################################################################
# Orkid Build System
# Copyright 2010-2018, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

import os, tarfile, sys
from obt import dep, host, path, git, cmake, make
from obt.deco import Deco
from obt.wget import wget
from obt.command import Command

sys.path.append(os.path.dirname(os.path.abspath(__file__)))

import _binutils

deco = Deco()

###############################################################################

class irix65_binutils(dep.StdProvider):

    def __init__(self): ############################################
        super().__init__("mips_irix65_binutils")
        self._archlist = ["x86_64"]

    ########

    def __str__(self):
        return "MIPS/IRIX65 BinUtils (source)"

    ########

    def build(self): ##########################################################

        bu = _binutils.context(self)

        os.mkdir(self.build_dest)
        os.chdir(self.build_dest)

        toolchain_dir = path.prefix()/"opt"/"toolchain"/"mips-sgi-irix6.5"

        ok = Command(['../%s/configure'%bu.name,
                      '--prefix=%s'%toolchain_dir,
                      '--target=mips-sgi-irix6.5',
                      '--program-prefix=mips-sgi-irix6.5-',
                      '--disable-werror',
                      '--disable-nls']).exec()==0

        return make.exec("all")==0

    def install(self): ##########################################################
        os.chdir(self.build_dest)
        return make.exec("install",parallelism=0.0)==0



#!/usr/bin/env python3

import cairo, math, os, time, jinja2
from orkbb import BranchStatus

w = 300
h = 300

TEMPLATETEXT = """
<svg xmlns="http://www.w3.org/2000/svg" width="{{ left.width + right.width }}" height="18">
  <linearGradient id="smooth" x2="0" y2="100%">
    <stop offset="0"  stop-color="#fff" stop-opacity=".7"/>
    <stop offset=".1" stop-color="#aaa" stop-opacity=".1"/>
    <stop offset=".9" stop-color="#000" stop-opacity=".3"/>
    <stop offset="1"  stop-color="#000" stop-opacity=".5"/>
  </linearGradient>
  <rect rx="4" width="{{ left.width + right.width }}" height="18" fill="{{ left.color }}"/>
  <rect rx="4" x="{{ left.width }}" width="{{ right.width }}" height="18" fill="{{ right.color }}"/>
  <rect x="{{ left.width }}" width="4" height="18" fill="{{ right.color }}"/>
  <rect rx="4" width="{{ left.width+right.width }}" height="18" fill="url(#smooth)"/>
  <g fill="#fff" text-anchor="middle" font-family="DejaVu Sans,Verdana,Geneva,sans-serif" font-size="11">
    <text x="{{ left.width/2+1 }}" y="14" fill="#010101" fill-opacity=".3">{{ left.text }}</text>
    <text x="{{ left.width/2+1 }}" y="13">{{ left.text }}</text>
    <text x="{{ left.width+right.width/2-1 }}" y="14" fill="#010101" fill-opacity=".3">{{ right.text }}</text>
    <text x="{{ left.width+right.width/2-1 }}" y="13">{{ right.text }}</text>
  </g>
</svg>
"""

def load_template(name):
  return TEMPLATETEXT

env = jinja2.Environment(
    loader=jinja2.FunctionLoader(load_template),
    autoescape=jinja2.select_autoescape(['html', 'xml'])
)
template = env.get_template('index.html')


surface = cairo.SVGSurface("dummy.svg", w, h)
context = cairo.Context(surface)
context.select_font_face("Graph", cairo.FONT_SLANT_NORMAL, cairo.FONT_WEIGHT_NORMAL)
context.set_font_size(16)

def _create(outpath = None,
            left_text=None,
            left_color=None,
            right_text=None,
            right_color=None ):

 left = {
        "color": left_color,
        "text": left_text,
        "width": context.text_extents(left_text).width
 }
 right = {
        "color": right_color,
        "text": right_text,
        "width": context.text_extents(right_text).width
 }

 template = env.get_template("yo")
 output = template.render(left=left, right=right)
 with open(outpath,"w") as f:
   f.write(output)


################################################################################

class Data:
  #######################################################################
  def __init__(self):
    self._leftcolor = "#202040"
    self._rightcolor = "#000000"
    self._lefttext = "BuildStatus"
    self._righttext = "???"
    self._outpath = "???"
  #######################################################################
  def create(self):
    _create( outpath=self._outpath,
             left_text=self._lefttext,right_text=self._righttext,
             left_color=self._leftcolor,right_color=self._rightcolor)
  #######################################################################
  def updateStatus(self,curstatus,prvstatus):
     ##################################
     # set text
     ##################################
     if curstatus==BranchStatus.PASSED:
       self._righttext = "PASSED"
     elif curstatus==BranchStatus.FAILED:
       self._righttext = "FAILED"
     elif curstatus==BranchStatus.INIT:
       self._righttext = "INIT"
     elif curstatus==BranchStatus.BUILDING:
       self._righttext = "BUILDING"
     else:
       self._righttext = "????"
     ##################################
     # set color
     ##################################
     self._rightcolor = "#000000"
     if curstatus==BranchStatus.PASSED:
       self._rightcolor = "#006000"
     elif curstatus==BranchStatus.FAILED:
       self._rightcolor = "#500000"
     elif curstatus==BranchStatus.INIT:
       self._rightcolor = "#000000"
     elif curstatus==BranchStatus.BUILDING:
       if prvstatus==BranchStatus.PASSED:
         self._rightcolor = "#006000"
       elif prvstatus==BranchStatus.FAILED:
         self._rightcolor = "#500000"
       elif prvstatus==BranchStatus.INIT:
         self._rightcolor = "#404040"



###############################################################################
# Orkid Build System
# Copyright 2010-2018, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

import glob, re, string, sys, os, shutil, fnmatch

###############################################################################

def builddir_replace( filelist, searchkey, replacekey ):
	a = [s.replace(searchkey,replacekey) for s in filelist]
	#print a
	return a

###############################################################################

def replace( file, searchkey, replacekey ):
	regex = re.compile( searchkey )
	str_file = str(file)
	str_rep = regex.sub( replacekey, string.join( str_file, '' ) )
	return posixpath(str_rep)

###############################################################################

def rmdirforce(basepath):
	if os.path.isdir(basepath):
		for root, dirs, files in os.walk(basepath, topdown=False):
			for name in files:
				os.remove(os.path.join(root, name))
			for name in dirs:
				os.rmdir(os.path.join(root, name))
		os.rmdir(basepath)


###############################################################################

def RunUnitTest(env,target,source):
	import subprocess
	app = str(source[0].abspath)
	if not subprocess.call(app):
		open(str(target[0]),'w').write("PASSED\n")




###############################################################################
# Orkid Build System
# Copyright 2010-2020, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################
from obt import dep, log, path, template
from obt import command 
###############################################################################
class pipewire(dep.StdProvider):
  name = "pipewire"
  def __init__(self):
    super().__init__(pipewire.name)
    self._builder = self.createBuilder(dep.CustomBuilder)

    def configure_pw(key,val):
      f2 = command.factory(prefix=["meson","configure",".build"],wdir=self.source_root)
      self._builder._incrbuildcommands += [f2.cmd("-D%s=%s"%(key,str(val)))]

    pw_meson = command.factory(prefix=["meson"],wdir=self.source_root)
    self._builder._cleanbuildcommands = [pw_meson.cmd("setup",".build")]
    configure_pw("prefix",path.stage())
    configure_pw("systemd-user-service","disabled")
    configure_pw("session-managers","['wireplumber']")
    configure_pw("udevrulesdir",path.stage()/"udevrules")
    configure_pw("includedir",path.stage()/"include")
    configure_pw("dbus","disabled")
    configure_pw("alsa","enabled")
    #configure_pw("pipewire-alsa","enabled")
    configure_pw("libdir",path.stage()/"lib")
    
    
    # systemd-system-unit-dir : /usr/lib/systemd/system
    # systemd-user-unit-dir   : /usr/lib/systemd/user
    # udevrulesdir : /lib/udev/rules.d

    self._builder._incrbuildcommands += [pw_meson.cmd("configure",".build")]
    if True:
      self._builder._incrbuildcommands += [pw_meson.cmd("compile","-C",".build")]
      self._builder._installcommands  = [pw_meson.cmd("install","-C",".build")]

    # PIPEWIRE_CONFIG_DIR=${OBT_STAGE}/etc pipewire

  ########################################################################
  @property
  def _fetcher(self):
    return dep.GithubFetcher(name=pipewire.name,
                             repospec="PipeWire/pipewire",
                             revision="0.3.83",
                             recursive=False)

  ########################################################################
  def areRequiredSourceFilesPresent(self):
    return (self.source_root/"LICENSE").exists()

  def areRequiredBinaryFilesPresent(self):
    return (path.libs()/"libPtex.so").exists()
###############################################################################







#!/usr/bin/env python3

###############################################################################
# Orkid Build System
# Copyright 2010-2022, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

###########################################

import pathlib, os, sys, getpass

###########################################
# setup sys.path so we can import _obt_config
###########################################

Path = pathlib.Path
curwd = Path(os.getcwd())
file_path = os.path.realpath(__file__)
file_dir = os.path.dirname(file_path)
sys.path.append(str(file_dir))

###########################################
# minimal (stageless) OBT support for non-environment shell
###########################################

from _obt_config import configFromCommandLine
obt_config = configFromCommandLine()
from obt import path, pathtools, env, command, deco
deco = deco.Deco()

###########################################
UID = os.getuid()
USERNAME = getpass.getuser()
HOMEDIR = os.environ["HOME"]

print(deco.cyan("installing uidmap"))
command.run(["sudo","apt","install","uidmap", "dbus-user-session"],do_log=True)

#disable system scoped docker daemon
print(deco.cyan("disabling system scoped docker"))
command.run(["sudo","systemctl","disable","--now","docker.service","docker.socket"],do_log=True)
command.system(["curl","-fsSL","https://get.docker.com/rootless","|","sh"],do_log=True)
print(deco.cyan("docker installed!"))

print(deco.cyan("allowing rootless docker to run when logged out"))
command.run(["sudo","loginctl","enable-linger",USERNAME],do_log=True)

print(deco.orange("add the following to your .bashrc:"))
print(deco.yellow("export PATH=%s/bin:$PATH"%HOMEDIR))
print(deco.yellow("export DOCKER_HOST=unix:///run/user/%d/docker.sock"%UID))
print(deco.yellow("ALSO: see https://docs.docker.com/go/rootless/"))


#!/usr/bin/env python3

import os, sys, subprocess, pathlib
import ci_common

########################################################

this_dir = os.path.dirname(os.path.realpath(__file__))
this_dir = pathlib.Path(os.path.abspath(this_dir))
orkidci_dir = this_dir/".."

########################################################
# we need an ssh key for the worker to git clone with
#  use a CICD key with read only access, not your personal key
# as it could be exposed by the build of products
########################################################

secrets_dir = os.environ["SECRETSDIR"]
private_key = secrets_dir/"buildkey.rsa"
public_key = secrets_dir/"buildkey.rsa.pub"

andtest_dir = orkidci_dir/"tests"/"android"

########################################################

cmdlist = list()

cmdlist += ["docker","run"]
cmdlist += ['-v',"%s:/home/android/.ssh/id_rsa:ro"%str(private_key)]
cmdlist += ['-v',"%s:/home/android/.ssh/id_rsa.pub:ro"%str(public_key)]
cmdlist += ['-v',"%s:/home/android/android_test:rw"%str(andtest_dir)]
cmdlist += ['-it','obtcicd/worker_android','/bin/bash']

########################################################

ci_common.sync_subprocess(cmdlist)



#!/usr/bin/env python3

###############################################################################
# Orkid Build System
# Copyright 2010-2022, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

import os, sys, pathlib, argparse, string
import obt.sdk

parser = argparse.ArgumentParser(description='obt.build sdk information')
parser.add_argument('sdk', metavar='S', type=str, help='a sdk you want information on')

_args = vars(parser.parse_args())

if len(sys.argv)==1:
    print(parser.format_usage())
    sys.exit(1)

sdkid = _args["sdk"]

target_arch = sdkid.split('-')[0]
target_os = sdkid.split('-')[1]

S = obt.sdk.descriptor(target_arch,target_os)

if S==None:
  print("SDK not supported on hosts")
  sys.exit(-1)

from obt import dep, path
from obt.deco import Deco
deco = Deco()

sdkid = "%s-%s" % (S.architecture,S.os)

def print_item(key,val):
 dstr = deco.inf(sdkid)
 kstr = deco.key(key)
 vstr = deco.val(val)
 print("%s.%s = %s"%(dstr,kstr,vstr))

print_item("identifier",S.identifier)
print_item("c_compiler",S.c_compiler)
print_item("cxx_compiler",S.cxx_compiler)
print_item("supports host",S.supports_host)
print_item("misc",S.misc())
#print_item("sdkdir",S.sdkdir)
